@@ -2,9 +2,9 @@
 
 /* Metacity X window decorations */
 
-/* 
+/*
  * Copyright (C) 2001 Havoc Pennington
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
@@ -14,7 +14,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
@@ -25,17 +25,6 @@
 #include "frame.h"
 #include "window-private.h"
 
-typedef struct _MetaFrameGeometry MetaFrameGeometry;
-
-struct _MetaFrameGeometry
-{  
-  /* border sizes (space between frame and child) */
-  int left_width;
-  int right_width;
-  int top_height;
-  int bottom_height;
-};
-
 struct _MetaFrame
 {
   /* window we frame */
@@ -69,8 +58,8 @@ void     meta_frame_queue_draw              (MetaFrame  *frame);
 MetaFrameFlags meta_frame_get_flags (MetaFrame *frame);
 
 /* These should ONLY be called from meta_window_move_resize_internal */
-void meta_frame_calc_geometry      (MetaFrame         *frame,
-                                    MetaFrameGeometry *geomp);
+void meta_frame_calc_borders       (MetaFrame         *frame,
+                                    MetaFrameBorders  *borders);
 void meta_frame_sync_to_window     (MetaFrame         *frame,
                                     int                gravity,
                                     gboolean           need_move,
