@@ -2,12 +2,12 @@
 
 /* Metacity window placement */
 
-/* 
+/*
  * Copyright (C) 2001 Havoc Pennington
  * Copyright (C) 2002, 2003 Red Hat, Inc.
  * Copyright (C) 2003 Rob Adams
  * Copyright (C) 2005 Elijah Newren
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
@@ -17,7 +17,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
@@ -72,11 +72,11 @@ northwestcmp (gconstpointer a, gconstpointer b)
       bx = bw->rect.x;
       by = bw->rect.y;
     }
-  
+
   /* probably there's a fast good-enough-guess we could use here. */
   from_origin_a = sqrt (ax * ax + ay * ay);
   from_origin_b = sqrt (bx * bx + by * by);
-    
+
   if (from_origin_a < from_origin_b)
     return -1;
   else if (from_origin_a > from_origin_b)
@@ -87,7 +87,7 @@ northwestcmp (gconstpointer a, gconstpointer b)
 
 static void
 find_next_cascade (MetaWindow *window,
-                   MetaFrameGeometry *fgeom,
+                   MetaFrameBorders *borders,
                    /* visible windows on relevant workspaces */
                    GList      *windows,
                    int         x,
@@ -103,31 +103,31 @@ find_next_cascade (MetaWindow *window,
   int cascade_stage;
   MetaRectangle work_area;
   const MetaXineramaScreenInfo* current;
-  
+
   sorted = g_list_copy (windows);
   sorted = g_list_sort (sorted, northwestcmp);
 
-  /* This is a "fuzzy" cascade algorithm. 
+  /* This is a "fuzzy" cascade algorithm.
    * For each window in the list, we find where we'd cascade a
    * new window after it. If a window is already nearly at that
    * position, we move on.
    */
-  
+
   /* arbitrary-ish threshold, honors user attempts to
    * manually cascade.
    */
 #define CASCADE_FUZZ 15
-  if (fgeom)
+  if (borders)
     {
-      x_threshold = MAX (fgeom->left_width, CASCADE_FUZZ);
-      y_threshold = MAX (fgeom->top_height, CASCADE_FUZZ);
+      x_threshold = MAX (borders->visible.left, CASCADE_FUZZ);
+      y_threshold = MAX (borders->visible.top, CASCADE_FUZZ);
     }
   else
     {
       x_threshold = CASCADE_FUZZ;
       y_threshold = CASCADE_FUZZ;
     }
-  
+
   /* Find furthest-SE origin of all workspaces.
    * cascade_x, cascade_y are the target position
    * of NW corner of window frame.
@@ -138,19 +138,19 @@ find_next_cascade (MetaWindow *window,
 
   cascade_x = MAX (0, work_area.x);
   cascade_y = MAX (0, work_area.y);
-  
+
   /* Find first cascade position that's not used. */
-  
+
   window_width = window->frame ? window->frame->rect.width : window->rect.width;
   window_height = window->frame ? window->frame->rect.height : window->rect.height;
-  
+
   cascade_stage = 0;
   tmp = sorted;
   while (tmp != NULL)
     {
       MetaWindow *w;
       int wx, wy;
-      
+
       w = tmp->data;
 
       /* we want frame position, not window position */
@@ -164,7 +164,7 @@ find_next_cascade (MetaWindow *window,
           wx = w->rect.x;
           wy = w->rect.y;
         }
-      
+
       if (ABS (wx - cascade_x) < x_threshold &&
           ABS (wy - cascade_y) < y_threshold)
         {
@@ -175,7 +175,7 @@ find_next_cascade (MetaWindow *window,
           meta_window_get_position (w, &wx, &wy);
           cascade_x = wx;
           cascade_y = wy;
-          
+
           /* If we go off the screen, start over with a new cascade */
 	  if (((cascade_x + window_width) >
                (work_area.x + work_area.width)) ||
@@ -184,11 +184,11 @@ find_next_cascade (MetaWindow *window,
 	    {
 	      cascade_x = MAX (0, work_area.x);
 	      cascade_y = MAX (0, work_area.y);
-              
+
 #define CASCADE_INTERVAL 50 /* space between top-left corners of cascades */
               cascade_stage += 1;
 	      cascade_x += CASCADE_INTERVAL * cascade_stage;
-              
+
 	      /* start over with a new cascade translated to the right, unless
                * we are out of space
                */
@@ -210,32 +210,32 @@ find_next_cascade (MetaWindow *window,
         {
           /* Keep searching for a further-down-the-diagonal window. */
         }
-        
+
       tmp = tmp->next;
     }
 
   /* cascade_x and cascade_y will match the last window in the list
    * that was "in the way" (in the approximate cascade diagonal)
    */
-  
+
   g_list_free (sorted);
 
   /* Convert coords to position of window, not position of frame. */
-  if (fgeom == NULL)
+  if (borders == NULL)
     {
       *new_x = cascade_x;
       *new_y = cascade_y;
     }
   else
     {
-      *new_x = cascade_x + fgeom->left_width;
-      *new_y = cascade_y + fgeom->top_height;
+      *new_x = cascade_x + borders->visible.left;
+      *new_y = cascade_y + borders->visible.top;
     }
 }
 
 static void
 find_most_freespace (MetaWindow *window,
-                     MetaFrameGeometry *fgeom,
+                     MetaFrameBorders *borders,
                      /* visible windows on relevant workspaces */
                      MetaWindow *focus_window,
                      int         x,
@@ -252,8 +252,8 @@ find_most_freespace (MetaWindow *window,
   MetaRectangle avoid;
   MetaRectangle outer;
 
-  frame_size_left = fgeom ? fgeom->left_width : 0;
-  frame_size_top  = fgeom ? fgeom->top_height : 0;
+  frame_size_left = borders ? borders->visible.left : 0;
+  frame_size_top  = borders ? borders->visible.top : 0;
 
   meta_window_get_work_area_current_xinerama (focus_window, &work_area);
   meta_window_get_outer_rect (focus_window, &avoid);
@@ -333,7 +333,7 @@ find_most_freespace (MetaWindow *window,
 
 static void
 avoid_being_obscured_as_second_modal_dialog (MetaWindow *window,
-                                             MetaFrameGeometry *fgeom,
+                                             MetaFrameBorders *borders,
                                              int        *x,
                                              int        *y)
 {
@@ -363,7 +363,7 @@ avoid_being_obscured_as_second_modal_dialog (MetaWindow *window,
                                 &focus_window->rect,
                                 &overlap))
     {
-      find_most_freespace (window, fgeom, focus_window, *x, *y, x, y);
+      find_most_freespace (window, borders, focus_window, *x, *y, x, y);
       meta_topic (META_DEBUG_PLACEMENT,
                   "Dialog window %s was denied focus but may be modal "
                   "to the focus window; had to move it to avoid the "
@@ -378,12 +378,12 @@ rectangle_overlaps_some_window (MetaRectangle *rect,
 {
   GList *tmp;
   MetaRectangle dest;
-  
+
   tmp = windows;
   while (tmp != NULL)
     {
       MetaWindow *other = tmp->data;
-      MetaRectangle other_rect;      
+      MetaRectangle other_rect;
 
       switch (other->type)
         {
@@ -399,12 +399,12 @@ rectangle_overlaps_some_window (MetaRectangle *rect,
         case META_WINDOW_TOOLBAR:
         case META_WINDOW_MENU:
           meta_window_get_outer_rect (other, &other_rect);
-          
+
           if (meta_rectangle_intersect (rect, &other_rect, &dest))
             return TRUE;
           break;
         }
-      
+
       tmp = tmp->next;
     }
 
@@ -495,7 +495,7 @@ center_tile_rect_in_area (MetaRectangle *rect,
  */
 static gboolean
 find_first_fit (MetaWindow *window,
-                MetaFrameGeometry *fgeom,
+                MetaFrameBorders *borders,
                 /* visible windows on relevant workspaces */
                 GList      *windows,
 		int         xinerama,
@@ -510,33 +510,33 @@ find_first_fit (MetaWindow *window,
    * the bottom of each existing window, and then to the right
    * of each existing window, aligned with the left/top of the
    * existing window in each of those cases.
-   */  
+   */
   int retval;
   GList *below_sorted;
   GList *right_sorted;
   GList *tmp;
   MetaRectangle rect;
   MetaRectangle work_area;
-  
+
   retval = FALSE;
 
   /* Below each window */
   below_sorted = g_list_copy (windows);
   below_sorted = g_list_sort (below_sorted, leftmost_cmp);
-  below_sorted = g_list_sort (below_sorted, topmost_cmp);  
+  below_sorted = g_list_sort (below_sorted, topmost_cmp);
 
   /* To the right of each window */
   right_sorted = g_list_copy (windows);
   right_sorted = g_list_sort (right_sorted, topmost_cmp);
   right_sorted = g_list_sort (right_sorted, leftmost_cmp);
-  
+
   rect.width = window->rect.width;
   rect.height = window->rect.height;
-  
-  if (fgeom)
+
+  if (borders)
     {
-      rect.width += fgeom->left_width + fgeom->right_width;
-      rect.height += fgeom->top_height + fgeom->bottom_height;
+      rect.width += borders->visible.left + borders->visible.right;
+      rect.height += borders->visible.top + borders->visible.bottom;
     }
 
 #ifdef WITH_VERBOSE_MODE
@@ -559,14 +559,14 @@ find_first_fit (MetaWindow *window,
       {
         *new_x = rect.x;
         *new_y = rect.y;
-        if (fgeom)
+        if (borders)
           {
-            *new_x += fgeom->left_width;
-            *new_y += fgeom->top_height;
+            *new_x += borders->visible.left;
+            *new_y += borders->visible.top;
           }
-    
+
         retval = TRUE;
-       
+
         goto out;
       }
 
@@ -578,23 +578,23 @@ find_first_fit (MetaWindow *window,
         MetaRectangle outer_rect;
 
         meta_window_get_outer_rect (w, &outer_rect);
-      
+
         rect.x = outer_rect.x;
         rect.y = outer_rect.y + outer_rect.height;
-      
+
         if (meta_rectangle_contains_rect (&work_area, &rect) &&
             !rectangle_overlaps_some_window (&rect, below_sorted))
           {
             *new_x = rect.x;
             *new_y = rect.y;
-            if (fgeom)
+            if (borders)
               {
-                *new_x += fgeom->left_width;
-                *new_y += fgeom->top_height;
+                *new_x += borders->visible.left;
+                *new_y += borders->visible.top;
               }
-          
+
             retval = TRUE;
-          
+
             goto out;
           }
 
@@ -607,31 +607,31 @@ find_first_fit (MetaWindow *window,
       {
         MetaWindow *w = tmp->data;
         MetaRectangle outer_rect;
-   
+
         meta_window_get_outer_rect (w, &outer_rect);
-     
+
         rect.x = outer_rect.x + outer_rect.width;
         rect.y = outer_rect.y;
-   
+
         if (meta_rectangle_contains_rect (&work_area, &rect) &&
             !rectangle_overlaps_some_window (&rect, right_sorted))
           {
             *new_x = rect.x;
             *new_y = rect.y;
-            if (fgeom)
+            if (borders)
               {
-                *new_x += fgeom->left_width;
-                *new_y += fgeom->top_height;
+                *new_x += borders->visible.left;
+                *new_y += borders->visible.top;
               }
-        
+
             retval = TRUE;
-       
+
             goto out;
           }
 
         tmp = tmp->next;
       }
-      
+
  out:
 
   g_list_free (below_sorted);
@@ -641,7 +641,7 @@ find_first_fit (MetaWindow *window,
 
 static gboolean
 find_preferred_position (MetaWindow *window,
-                         MetaFrameGeometry *fgeom,
+                         MetaFrameBorders *borders,
                          /* visible windows on relevant workspaces */
                          GList      *windows,
                          int         xinerama,
@@ -660,7 +660,7 @@ find_preferred_position (MetaWindow *window,
    */
   if (placement_mode_pref == META_PLACEMENT_MODE_SMART)
     {
-      return find_first_fit (window, fgeom, windows,
+      return find_first_fit (window, borders, windows,
                              xinerama,
                              x, y, new_x, new_y);
     }
@@ -670,17 +670,17 @@ find_preferred_position (MetaWindow *window,
        * intended for this use, and because it is not designed to
        * deal with placement on multiple Xineramas.
        */
-      find_next_cascade (window, fgeom, windows, x, y, new_x, new_y);
+      find_next_cascade (window, borders, windows, x, y, new_x, new_y);
       return TRUE;
     }
 
   rect.width = window->rect.width;
   rect.height = window->rect.height;
 
-  if (fgeom)
+  if (borders)
     {
-      rect.width += fgeom->left_width + fgeom->right_width;
-      rect.height += fgeom->top_height + fgeom->bottom_height;
+      rect.width += borders->visible.left + borders->visible.right;
+      rect.height += borders->visible.top + borders->visible.bottom;
     }
 
   meta_window_get_work_area_for_xinerama (window, xinerama, &work_area);
@@ -719,10 +719,10 @@ find_preferred_position (MetaWindow *window,
             break;
         }
 
-      if (fgeom)
+      if (borders)
         {
-          *new_x += fgeom->left_width;
-          *new_y += fgeom->top_height;
+          *new_x += borders->visible.left;
+          *new_y += borders->visible.top;
         }
 
       return TRUE;
@@ -733,7 +733,7 @@ find_preferred_position (MetaWindow *window,
 
 void
 meta_window_place (MetaWindow        *window,
-                   MetaFrameGeometry *fgeom,
+                   MetaFrameBorders  *borders,
                    int                x,
                    int                y,
                    int               *new_x,
@@ -743,16 +743,16 @@ meta_window_place (MetaWindow        *window,
   const MetaXineramaScreenInfo *xi;
 
   /* frame member variables should NEVER be used in here, only
-   * MetaFrameGeometry. But remember fgeom == NULL
+   * MetaFrameBorders. But remember borders == NULL
    * for undecorated windows. Also, this function should
    * NEVER have side effects other than computing the
    * placement coordinates.
    */
-  
+
   meta_topic (META_DEBUG_PLACEMENT, "Placing window %s\n", window->desc);
 
   windows = NULL;
-  
+
   switch (window->type)
     {
       /* Run placement algorithm on these. */
@@ -761,7 +761,7 @@ meta_window_place (MetaWindow        *window,
     case META_WINDOW_MODAL_DIALOG:
     case META_WINDOW_SPLASHSCREEN:
       break;
-          
+
       /* Assume the app knows best how to place these, no placement
        * algorithm ever (other than "leave them as-is")
        */
@@ -772,7 +772,7 @@ meta_window_place (MetaWindow        *window,
     case META_WINDOW_UTILITY:
       goto done_no_constraints;
     }
-  
+
   if (meta_prefs_get_disable_workarounds ())
     {
       switch (window->type)
@@ -796,7 +796,7 @@ meta_window_place (MetaWindow        *window,
         case META_WINDOW_MODAL_DIALOG:
         case META_WINDOW_SPLASHSCREEN:
           break;
-          
+
           /* Assume the app knows best how to place these. */
         case META_WINDOW_DESKTOP:
         case META_WINDOW_DOCK:
@@ -815,17 +815,17 @@ meta_window_place (MetaWindow        *window,
   else
     {
       /* workarounds enabled */
-      
+
       if ((window->size_hints.flags & PPosition) ||
           (window->size_hints.flags & USPosition))
         {
           meta_topic (META_DEBUG_PLACEMENT,
                       "Not placing window with PPosition or USPosition set\n");
-          avoid_being_obscured_as_second_modal_dialog (window, fgeom, &x, &y);
+          avoid_being_obscured_as_second_modal_dialog (window, borders, &x, &y);
           goto done_no_constraints;
         }
     }
-  
+
   if ((window->type == META_WINDOW_DIALOG ||
        window->type == META_WINDOW_MODAL_DIALOG) &&
       window->xtransient_for != None)
@@ -833,7 +833,7 @@ meta_window_place (MetaWindow        *window,
       /* Center horizontally, at top of parent vertically */
 
       MetaWindow *parent;
-          
+
       parent =
         meta_display_lookup_x_window (window->display,
                                       window->xtransient_for);
@@ -856,22 +856,22 @@ meta_window_place (MetaWindow        *window,
           y += (parent->rect.height - window->rect.height)/3;
 
           /* put top of child's frame, not top of child's client */
-          if (fgeom)
-            y += fgeom->top_height;
+          if (borders)
+            y += borders->visible.top;
 
           meta_topic (META_DEBUG_PLACEMENT, "Centered window %s over transient parent\n",
                       window->desc);
-          
-          avoid_being_obscured_as_second_modal_dialog (window, fgeom, &x, &y);
+
+          avoid_being_obscured_as_second_modal_dialog (window, borders, &x, &y);
 
           goto done;
         }
     }
-  
+
   /* FIXME UTILITY with transient set should be stacked up
    * on the sides of the parent window or something.
    */
-  
+
   if (window->type == META_WINDOW_DIALOG ||
       window->type == META_WINDOW_MODAL_DIALOG ||
       window->type == META_WINDOW_SPLASHSCREEN)
@@ -890,13 +890,13 @@ meta_window_place (MetaWindow        *window,
 
       x += xi->rect.x;
       y += xi->rect.y;
-      
+
       meta_topic (META_DEBUG_PLACEMENT, "Centered window %s on screen %d xinerama %d\n",
                   window->desc, window->screen->number, xi->number);
 
       goto done_check_denied_focus;
     }
-  
+
   /* Find windows that matter (not minimized, on same workspace
    * as placed window, may be shaded - if shaded we pretend it isn't
    * for placement purposes)
@@ -904,7 +904,7 @@ meta_window_place (MetaWindow        *window,
   {
     GSList *all_windows;
     GSList *tmp;
-    
+
     all_windows = meta_display_list_windows (window->display);
 
     tmp = all_windows;
@@ -913,7 +913,7 @@ meta_window_place (MetaWindow        *window,
         MetaWindow *w = tmp->data;
 
         if (meta_window_showing_on_its_workspace (w) &&
-            w != window && 
+            w != window &&
             (window->workspace == w->workspace ||
              window->on_all_workspaces || w->on_all_workspaces))
           windows = g_list_prepend (windows, w);
@@ -926,19 +926,19 @@ meta_window_place (MetaWindow        *window,
 
   /* Warning, this is a round trip! */
   xi = meta_screen_get_current_xinerama (window->screen);
-  
+
   /* "Origin" placement algorithm */
   x = xi->rect.x;
   y = xi->rect.y;
 
-  if (find_preferred_position (window, fgeom, windows,
+  if (find_preferred_position (window, borders, windows,
                                xi->number,
                                x, y, &x, &y))
     goto done_check_denied_focus;
 
   /* Maximize windows if they are too big for their work area (bit of
    * a hack here). Assume undecorated windows probably don't intend to
-   * be maximized.  
+   * be maximized.
    */
   if (window->has_maximize_func && window->decorated &&
       !window->fullscreen)
@@ -948,9 +948,9 @@ meta_window_place (MetaWindow        *window,
 
       meta_window_get_work_area_for_xinerama (window,
                                               xi->number,
-                                              &workarea);      
+                                              &workarea);
       meta_window_get_outer_rect (window, &outer);
-      
+
       /* If the window is bigger than the screen, then automaximize.  Do NOT
        * auto-maximize the directions independently.  See #419810.
        */
@@ -961,11 +961,11 @@ meta_window_place (MetaWindow        *window,
         }
     }
 
-  /* If no placement has been done, revert to cascade to avoid 
+  /* If no placement has been done, revert to cascade to avoid
    * fully overlapping window (e.g. starting multiple terminals)
    * */
-  if (x == xi->rect.x && y == xi->rect.y)  
-    find_next_cascade (window, fgeom, windows, x, y, &x, &y);
+  if (x == xi->rect.x && y == xi->rect.y)
+    find_next_cascade (window, borders, windows, x, y, &x, &y);
 
  done_check_denied_focus:
   /* If the window is being denied focus and isn't a transient of the
@@ -999,7 +999,7 @@ meta_window_place (MetaWindow        *window,
           x = xi->rect.x;
           y = xi->rect.y;
 
-          found_fit = find_first_fit (window, fgeom, focus_window_list,
+          found_fit = find_first_fit (window, borders, focus_window_list,
                                       xi->number,
                                       x, y, &x, &y);
           g_list_free (focus_window_list);
@@ -1009,12 +1009,12 @@ meta_window_place (MetaWindow        *window,
        * as possible.
        */
       if (!found_fit)
-        find_most_freespace (window, fgeom, focus_window, x, y, &x, &y);
+        find_most_freespace (window, borders, focus_window, x, y, &x, &y);
     }
-  
+
  done:
   g_list_free (windows);
-  
+
  done_no_constraints:
 
   *new_x = x;
