@@ -174,7 +174,7 @@ normal_contents (void)
   GtkWidget *contents;
   GtkWidget *sw;
   GtkBuilder *builder;
-      
+
   grid = gtk_grid_new ();
   builder = gtk_builder_new_from_string (xml, -1);
 
@@ -200,7 +200,7 @@ normal_contents (void)
 
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
                                        GTK_SHADOW_IN);
-      
+
   gtk_grid_attach (GTK_GRID (grid), sw, 0, 2, 1, 1);
 
   gtk_widget_set_hexpand (sw, TRUE);
@@ -209,7 +209,7 @@ normal_contents (void)
   contents = gtk_text_view_new ();
   gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (contents),
                                PANGO_WRAP_WORD);
-      
+
   gtk_container_add (GTK_CONTAINER (sw),
                      contents);
 
@@ -244,19 +244,19 @@ dialog_contents (void)
   GtkWidget *label;
   GtkWidget *image;
   GtkWidget *button;
-  
+
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
   action_area = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
 
   gtk_button_box_set_layout (GTK_BUTTON_BOX (action_area),
-                             GTK_BUTTONBOX_END);  
+                             GTK_BUTTONBOX_END);
 
   button = gtk_button_new_with_label (_("OK"));
   gtk_box_pack_end (GTK_BOX (action_area),
                     button,
                     FALSE, TRUE, 0);
-  
+
   gtk_box_pack_end (GTK_BOX (vbox), action_area,
                     FALSE, TRUE, 0);
 
@@ -264,11 +264,12 @@ dialog_contents (void)
 
   label = gtk_label_new (_("This is a sample message in a sample dialog"));
   image = gtk_image_new_from_icon_name ("dialog-information", GTK_ICON_SIZE_DIALOG);
-  gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-  
+  gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
+  gtk_widget_set_valign (image, GTK_ALIGN_START);
+
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
   gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-  
+
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 
   gtk_box_pack_start (GTK_BOX (hbox), image,
@@ -304,11 +305,11 @@ utility_contents (void)
           char *str;
 
           str = g_strdup_printf ("_%c", (char) ('A' + 4*i + j));
-          
+
           button = gtk_button_new_with_mnemonic (str);
 
           g_free (str);
-          
+
           gtk_grid_attach (GTK_GRID (grid), button, i, j, 1, 1);
 
           ++j;
@@ -318,7 +319,7 @@ utility_contents (void)
     }
 
   gtk_widget_show_all (grid);
-  
+
   return grid;
 }
 
@@ -326,7 +327,7 @@ static GtkWidget*
 menu_contents (void)
 {
   GtkWidget *vbox;
-  GtkWidget *mi;  
+  GtkWidget *mi;
   int i;
   GtkWidget *frame;
 
@@ -341,17 +342,18 @@ menu_contents (void)
     {
       char *str = g_strdup_printf (_("Fake menu item %d\n"), i + 1);
       mi = gtk_label_new (str);
-      gtk_misc_set_alignment (GTK_MISC (mi), 0.0, 0.5);
+      gtk_widget_set_halign (mi, GTK_ALIGN_START);
+      gtk_widget_set_valign (mi, GTK_ALIGN_CENTER);
       g_free (str);
       gtk_box_pack_start (GTK_BOX (vbox), mi, FALSE, FALSE, 0);
-      
+
       ++i;
     }
 
   gtk_container_add (GTK_CONTAINER (frame), vbox);
-  
+
   gtk_widget_show_all (frame);
-  
+
   return frame;
 }
 
@@ -370,19 +372,19 @@ border_only_contents (void)
   color.blue = 0.6;
   color.alpha = 1.0;
   gtk_widget_override_background_color (event_box, 0, &color);
-  
+
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 3);
-  
+
   w = gtk_label_new (_("Border-only window"));
   gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
   w = gtk_button_new_with_label (_("Bar"));
   gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 
   gtk_container_add (GTK_CONTAINER (event_box), vbox);
-  
+
   gtk_widget_show_all (event_box);
-  
+
   return event_box;
 }
 
@@ -415,7 +417,11 @@ get_window_contents (MetaFrameType  type,
     case META_FRAME_TYPE_BORDER:
       *title = _("Border");
       return border_only_contents ();
-      
+
+    case META_FRAME_TYPE_ATTACHED:
+      *title = _("Attached Modal Dialog");
+      return dialog_contents ();
+
     case META_FRAME_TYPE_LAST:
       g_assert_not_reached ();
       break;
@@ -438,7 +444,7 @@ get_window_flags (MetaFrameType type)
     META_FRAME_HAS_FOCUS |
     META_FRAME_ALLOWS_SHADE |
     META_FRAME_ALLOWS_MOVE;
-  
+
   switch (type)
     {
     case META_FRAME_TYPE_NORMAL:
@@ -462,12 +468,15 @@ get_window_flags (MetaFrameType type)
 
     case META_FRAME_TYPE_BORDER:
       break;
-      
+
+    case META_FRAME_TYPE_ATTACHED:
+      break;
+
     case META_FRAME_TYPE_LAST:
       g_assert_not_reached ();
       break;
-    }  
-  
+    }
+
   return flags;
 }
 
@@ -492,7 +501,7 @@ preview_collection (int font_size,
 
   eventbox = gtk_event_box_new ();
   gtk_container_add (GTK_CONTAINER (eventbox), box);
-  
+
   gtk_container_add (GTK_CONTAINER (sw), eventbox);
 
   GSimpleActionGroup *action_group = g_simple_action_group_new ();
@@ -521,23 +530,23 @@ preview_collection (int font_size,
       GtkWidget *preview;
       PangoFontDescription *font_desc;
       double scale;
-      
+
       eventbox2 = gtk_event_box_new ();
-      
+
       preview = meta_preview_new ();
-      
+
       gtk_container_add (GTK_CONTAINER (eventbox2), preview);
-      
+
       meta_preview_set_frame_type (META_PREVIEW (preview), i);
       meta_preview_set_frame_flags (META_PREVIEW (preview),
                                     get_window_flags (i));
-            
+
       meta_preview_set_theme (META_PREVIEW (preview), global_theme);
-      
+
       contents = get_window_contents (i, &title);
-      
+
       meta_preview_set_title (META_PREVIEW (preview), title);
-      
+
       gtk_container_add (GTK_CONTAINER (preview), contents);
 
       if (i == META_FRAME_TYPE_MENU)
@@ -550,10 +559,10 @@ preview_collection (int font_size,
           xalign = 0.5;
           yalign = 0.5;
         }
-      
+
       align = gtk_alignment_new (0.0, 0.0, xalign, yalign);
       gtk_container_add (GTK_CONTAINER (align), eventbox2);
-      
+
       gtk_box_pack_start (GTK_BOX (box), align, TRUE, TRUE, 0);
 
       switch (font_size)
@@ -572,17 +581,17 @@ preview_collection (int font_size,
       if (scale != 1.0)
         {
           font_desc = pango_font_description_new ();
-          
+
           pango_font_description_set_size (font_desc,
                                            MAX (pango_font_description_get_size (base_desc) * scale, 1));
-          
+
           gtk_widget_override_font (preview, font_desc);
 
           pango_font_description_free (font_desc);
         }
-      
+
       previews[font_size*META_FRAME_TYPE_LAST + i] = preview;
-      
+
       ++i;
     }
 
@@ -611,13 +620,13 @@ init_layouts (void)
         }
       ++i;
     }
-  
+
 #ifndef ALLOW_DUPLICATE_BUTTONS
   i = 0;
   while (i <= MAX_BUTTONS_PER_CORNER)
     {
       int j;
-      
+
       j = 0;
       while (j < i)
         {
@@ -629,34 +638,34 @@ init_layouts (void)
           different_layouts[i].left_buttons[j-i] = (MetaButtonFunction) j;
           ++j;
         }
-      
+
       ++i;
     }
 
   /* Special extra case for no buttons on either side */
   different_layouts[i].left_buttons[0] = META_BUTTON_FUNCTION_LAST;
   different_layouts[i].right_buttons[0] = META_BUTTON_FUNCTION_LAST;
-  
+
 #else
   /* FIXME this code is if we allow duplicate buttons,
    * which we currently do not
    */
   int left;
   int i;
-  
+
   left = 0;
   i = 0;
 
   while (left < MAX_BUTTONS_PER_CORNER)
     {
       int right;
-      
+
       right = 0;
-      
+
       while (right < MAX_BUTTONS_PER_CORNER)
         {
           int j;
-          
+
           static MetaButtonFunction left_functions[MAX_BUTTONS_PER_CORNER] = {
             META_BUTTON_FUNCTION_MENU,
             META_BUTTON_FUNCTION_MINIMIZE,
@@ -671,7 +680,7 @@ init_layouts (void)
           };
 
           g_assert (i < BUTTON_LAYOUT_COMBINATIONS);
-          
+
           j = 0;
           while (j <= left)
             {
@@ -685,12 +694,12 @@ init_layouts (void)
               different_layouts[i].right_buttons[j] = right_functions[j];
               ++j;
             }
-          
+
           ++i;
-          
+
           ++right;
         }
-      
+
       ++left;
     }
 #endif
@@ -706,13 +715,13 @@ previews_of_button_layouts (void)
   GdkRGBA desktop_color;
   int i;
   GtkWidget *eventbox;
-  
+
   if (!initted)
     {
       init_layouts ();
       initted = TRUE;
     }
-  
+
   sw = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
                                   GTK_POLICY_AUTOMATIC,
@@ -724,7 +733,7 @@ previews_of_button_layouts (void)
 
   eventbox = gtk_event_box_new ();
   gtk_container_add (GTK_CONTAINER (eventbox), box);
-  
+
   gtk_container_add (GTK_CONTAINER (sw), eventbox);
 
   desktop_color.red = 0.32;
@@ -744,11 +753,11 @@ previews_of_button_layouts (void)
       char *title;
 
       eventbox2 = gtk_event_box_new ();
-  
+
       preview = meta_preview_new ();
-  
-      gtk_container_add (GTK_CONTAINER (eventbox2), preview);  
-  
+
+      gtk_container_add (GTK_CONTAINER (eventbox2), preview);
+
       meta_preview_set_theme (META_PREVIEW (preview), global_theme);
 
       title = g_strdup_printf (_("Button layout test %d"), i+1);
@@ -757,20 +766,20 @@ previews_of_button_layouts (void)
 
       meta_preview_set_button_layout (META_PREVIEW (preview),
                                       &different_layouts[i]);
-  
+
       xalign = 0.5;
       yalign = 0.5;
-      
+
       align = gtk_alignment_new (0.0, 0.0, xalign, yalign);
       gtk_container_add (GTK_CONTAINER (align), eventbox2);
-  
+
       gtk_box_pack_start (GTK_BOX (box), align, TRUE, TRUE, 0);
 
       previews[META_FRAME_TYPE_LAST*FONT_SIZE_LAST + i] = preview;
-      
+
       ++i;
     }
-  
+
   return sw;
 }
 
@@ -779,7 +788,7 @@ benchmark_summary (void)
 {
   char *msg;
   GtkWidget *label;
-  
+
   msg = g_strdup_printf (_("%g milliseconds to draw one window frame"),
                          milliseconds_to_draw_frame);
   label = gtk_label_new (msg);
@@ -799,7 +808,7 @@ main (int argc, char **argv)
   clock_t start, end;
   GtkWidget *notebook;
   int i;
-  
+
   bindtextdomain (GETTEXT_PACKAGE, METACITY_LOCALEDIR);
   textdomain(GETTEXT_PACKAGE);
   bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
@@ -816,7 +825,7 @@ main (int argc, char **argv)
       meta_set_debugging (TRUE);
       meta_set_verbose (TRUE);
     }
-  
+
   start = clock ();
   err = NULL;
   if (argc == 1)
@@ -843,7 +852,7 @@ main (int argc, char **argv)
            (end - start) / (double) CLOCKS_PER_SEC);
 
   run_theme_benchmark ();
-  
+
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_default_size (GTK_WINDOW (window), 350, 350);
 
@@ -863,7 +872,7 @@ main (int argc, char **argv)
                             title);
 
       g_free (title);
-    }       
+    }
 
   g_signal_connect (G_OBJECT (window), "destroy",
                     G_CALLBACK (gtk_main_quit), NULL);
@@ -874,7 +883,7 @@ main (int argc, char **argv)
 
   g_assert (style);
   g_assert (font_desc);
-  
+
   notebook = gtk_notebook_new ();
   gtk_container_add (GTK_CONTAINER (window), notebook);
 
@@ -883,13 +892,13 @@ main (int argc, char **argv)
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
                             collection,
                             gtk_label_new (_("Normal Title Font")));
-  
+
   collection = preview_collection (FONT_SIZE_SMALL,
                                    font_desc);
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
                             collection,
                             gtk_label_new (_("Small Title Font")));
-  
+
   collection = preview_collection (FONT_SIZE_LARGE,
                                    font_desc);
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
@@ -918,7 +927,7 @@ main (int argc, char **argv)
 
       ++i;
     }
-  
+
   gtk_widget_show_all (window);
 
   gtk_main ();
@@ -971,7 +980,7 @@ run_theme_benchmark (void)
 {
   GtkWidget* widget;
   cairo_surface_t *pixmap;
-  int top_height, bottom_height, left_width, right_width;
+  MetaFrameBorders borders;
   MetaButtonState button_states[META_BUTTON_TYPE_LAST] =
   {
     META_BUTTON_STATE_NORMAL,
@@ -990,21 +999,18 @@ run_theme_benchmark (void)
   int client_height;
   cairo_t *cr;
   int inc;
-  
+
   widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_widget_realize (widget);
-  
+
   meta_theme_get_frame_borders (global_theme,
                                 META_FRAME_TYPE_NORMAL,
                                 get_text_height (widget),
                                 get_flags (widget),
-                                &top_height,
-                                &bottom_height,
-                                &left_width,
-                                &right_width);
-  
+                                &borders);
+
   layout = create_title_layout (widget);
-  
+
   i = 0;
   while (i < MAX_BUTTONS_PER_CORNER)
     {
@@ -1012,7 +1018,7 @@ run_theme_benchmark (void)
       button_layout.right_buttons[i] = META_BUTTON_FUNCTION_LAST;
       ++i;
     }
-  
+
   button_layout.left_buttons[0] = META_BUTTON_FUNCTION_MENU;
 
   button_layout.right_buttons[0] = META_BUTTON_FUNCTION_MINIMIZE;
@@ -1027,7 +1033,7 @@ run_theme_benchmark (void)
   inc = 1000 / ITERATIONS; /* Increment to grow width/height,
                             * eliminates caching effects.
                             */
-  
+
   i = 0;
   while (i < ITERATIONS)
     {
@@ -1036,8 +1042,8 @@ run_theme_benchmark (void)
        */
       pixmap = gdk_window_create_similar_surface (gtk_widget_get_window (widget),
                                                   CAIRO_CONTENT_COLOR,
-                                                  client_width + left_width + right_width,
-                                                  client_height + top_height + bottom_height);
+                                                  client_width + borders.visible.left + borders.visible.right,
+                                                  client_height + borders.visible.top + borders.visible.bottom);
       cr = cairo_create (pixmap);
 
       meta_theme_draw_frame (global_theme,
@@ -1055,7 +1061,7 @@ run_theme_benchmark (void)
 
       cairo_destroy (cr);
       cairo_surface_destroy (pixmap);
-      
+
       ++i;
       client_width += inc;
       client_height += inc;
@@ -1065,7 +1071,7 @@ run_theme_benchmark (void)
   g_timer_stop (timer);
 
   milliseconds_to_draw_frame = (g_timer_elapsed (timer, NULL) / (double) ITERATIONS) * 1000;
-  
+
   g_print (_("Drew %d frames in %g client-side seconds (%g milliseconds per frame) and %g seconds wall clock time including X server resources (%g milliseconds per frame)\n"),
            ITERATIONS,
            ((double)end - (double)start) / CLOCKS_PER_SEC,
@@ -1259,7 +1265,7 @@ run_position_expression_tests (void)
                  test->expr, test->expected_x, test->expected_y);
 
       err = NULL;
-      
+
       env.rect = meta_rect (test->rect.x, test->rect.y,
                             test->rect.width, test->rect.height);
       env.object_width = -1;
